// Event names
export const EVENT_USER_FOLLOWS_LINK_ON_HOMEPAGE = 'user_follows_link_on_homepage';
export const EVENT_USER_CLICKS_LINK_ON_ACTIVITY_FEED = 'user_clicks_link_in_activity_feed';

// Labels
export const TRACKING_LABEL_MERGE_REQUESTS = 'Merge requests';
export const TRACKING_LABEL_WORK_ITEMS = 'Issues';
export const TRACKING_LABEL_TODO_ITEMS = 'To-do items';
export const TRACKING_LABEL_RECENTLY_VIEWED = 'Recently viewed';
export const TRACKING_LABEL_FEEDBACK = 'Feedback';

// Properties
export const TRACKING_PROPERTY_REVIEW_REQUESTED = 'Review requested';
export const TRACKING_PROPERTY_ASSIGNED_TO_YOU = 'Assigned to you';
export const TRACKING_PROPERTY_AUTHORED_BY_YOU = 'Authored by you';
export const TRACKING_PROPERTY_ALL_TODOS = 'All to-dos';

// Scope
export const TRACKING_SCOPE_YOUR_ACTIVITY = 'Your activity';
export const TRACKING_SCOPE_STARRED_PROJECTS = 'Starred projects';
export const TRACKING_SCOPE_FOLLOWED_USERS = 'Followed users';
